@@ -4,7 +4,9 @@ use strict;
 use warnings;
 use utf8;
 
-sub new($ @) {
+our $VERSION = '0.07'; # VERSION
+
+sub new {
     my $this = shift;
     my $class = ref($this) || $this;
     my $self = {
